plotting
--------

.. currentmodule:: eqcorrscan.utils.plotting
.. automodule:: eqcorrscan.utils.plotting

All plotting functions accept the `save`, `savefile`, `title` and `show` keyword
arguments.

    .. comment to end block

    Classes & Functions
    -------------------
    .. autosummary::
       :toctree: autogen
       :nosignatures:

       chunk_data
       cumulative_detections
       detection_multiplot
       freq_mag
       interev_mag
       multi_event_singlechan
       obspy_3d_plot
       peaks_plot
       plot_repicked
       plot_synth_real
       pretty_template_plot
       spec_trace
       subspace_detector_plot
       svd_plot
       threeD_gridplot
       threeD_seismplot
       triple_plot
       xcorr_plot
       noise_plot

    .. comment to end block
